
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/doc/HTML/en/kwordquiz ; rm -rf common )
( cd usr/doc/HTML/en/kwordquiz ; ln -sf /usr/share/doc/HTML/en/common common )
